@@ -129,6 +129,11 @@ class Afs(BaseModelTimeAndDeleted):
     # 售后单同步信息
     sync_status = models.BooleanField('同步状态', default=False)
     sync_time = models.DateTimeField('售后单同步时间', null=True, blank=True)
+    
+    # 退款同步信息
+    afs_sync_status = models.BooleanField('退款同步状态', default=False)
+    afs_sync_time = models.DateTimeField('退款同步时间', null=True, blank=True)
+    
     store_reject_reason = models.CharField("店内系统拒绝理由", max_length=512,
                                            blank=True, null=True)
     # 客服给退单的备注
@@ -1087,3 +1092,40 @@ class DeliveryReturn(BaseModelTimeAndDeleted):
     class Meta:
         index_together = ["source_type", "source_id"]
         app_label = APP_LABEL
+
+
+
+
+class AfsHgIncome(BaseModelTimeAndDeleted):
+    '''
+    售后单营业外收入，与售后单Aftersale表关系为0/1对1，即一个售后单可以存在0个或者1个AfterSaleHgIncome
+    Afs表中的hg_income_cash字段会逐渐被本表中hg_income_cash替代，替代之后，Afs不应该有营业外收入的任何业务
+    '''
+    aftersale_id = models.IntegerField('AFS ID', primary_key=True, editable=False)
+    order_id = models.IntegerField('订单ID', blank=True, null=True, db_index=True)
+    hg_income_cash = models.DecimalField("用户补给汉光的现金额", decimal_places=2, max_digits=12, default=0)
+    # 同步线下时使用的订单编号，实际上该订单并不存在
+    hgincome_order_number = models.CharField("虚拟订单编号", max_length=32, blank=True, null=True)
+    # 同步信息
+    hgincome_sync_status = models.BooleanField('同步状态', default=False)
+    hgincome_sync_time = models.DateTimeField('同步时间', null=True, blank=True)
+    hgincome_sync_reject_reason = models.CharField("财务拒绝理由", max_length=512, blank=True, null=True)
+    class Meta:
+        app_label = 'sparrow_aftersale'
+
+
+class AfsHgIncomeDivide(BaseModelTimeAndDeleted):
+    '''
+    售后单营业外收入付款别分配表
+    指的是：营业外收入最终以哪些支付方式进行扣减
+    '''
+    id = models.CharField("id", primary_key=True, max_length=40, default=get_uuid4_hex)
+    order_id = models.IntegerField('订单ID', blank=True, null=True, db_index=True)
+    aftersale_id = models.IntegerField('AFS ID', blank=True, null=True, db_index=True)
+    divide_payment_type = models.IntegerField('营业外收入分配支付类型', blank=True, null=True, db_index=True)
+    divide_amount = models.DecimalField("营业外收入分配金额", decimal_places=2, max_digits=12, blank=True, null=True, default=0)
+    # pay_step_type 支付阶段(once全款/deposit定金/tail尾款)
+    pay_step_type = models.CharField("支付阶段", max_length=24, choices=PayStepType.PAY_STEP_TYPE_CHOICES, default=PayStepType.ONCE, db_index=True)
+    hgincome_type_id = models.IntegerField('hgincome Type ID', blank=True, null=True, db_index=True)
+    class Meta:
+        app_label = 'sparrow_aftersale'
\ No newline at end of file
